@@ -77,7 +77,15 @@ try {
 }
 catch (Exception $e) {
     $exc = $e->getMessage();
-    $App->log('Authentication error: '.$exc);
+    $msg = 'Authentication';
+    if ($App->getConfig('AUTHERROR_USERLOG')) {
+        $msg .= ' of '.$USER->id;
+    }
+    $msg .= ' failed';
+    if ($exc != 'ERR_AUTH') {
+        $msg .= ': '.$exc;
+    }
+    $App->log($msg);
     $redata['MSG'] = $exc;
     $App->redirect('default',$redata);
 }
