@@ -250,10 +250,23 @@ class UserDA extends Persistence
 
 
     // Overwrites Persistence::save()
-    function save ()
+    function save ($suffix='')
     {
         global $App;
 
+        if ($suffix) {
+            // username suffix to separate users in multi domain setup
+            $new_id = '';
+            if (strstr($this->id,'@')) {
+                list ($pfx,$sfx) = explode('@',$this->id,2);
+                $new_id = $pfx.'@'.$suffix;
+            }
+            else {
+                $new_id = $this->id.'@'.$suffix;
+            }
+            $this->id = $new_id;
+        }
+
         $DB = $App->DB;
         $DB->startTransaction();
         try {
@@ -382,7 +395,7 @@ class UserDA extends Persistence
         foreach ($retlines as $line) {
             $line = trim($line);
             if (!$line) continue;
-            list($mark,$data) = preg_split('/\s/',$line,2);
+            @list($mark,$data) = preg_split('/\s/',$line,2);
             switch ($mark) {
                 case 'ERROR':
                     throw new Exception($data);
